================
Panel Auth0 Oidc
================


.. image:: https://img.shields.io/pypi/v/panel_auth0_oidc.svg
        :target: https://pypi.python.org/pypi/panel_auth0_oidc

.. image:: https://img.shields.io/travis/jmosbacher/panel_auth0_oidc.svg
        :target: https://travis-ci.com/jmosbacher/panel_auth0_oidc

.. image:: https://readthedocs.org/projects/panel-auth0-oidc/badge/?version=latest
        :target: https://panel-auth0-oidc.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Oidc Auth0 oauth plugin for panel


* Free software: MIT
* Documentation: https://panel-auth0-oidc.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `briggySmalls/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`briggySmalls/cookiecutter-pypackage`: https://github.com/briggySmalls/cookiecutter-pypackage
